#!/bin/bash

GIT_URL="https://git.zelz.net/saige/bssh/raw/branch/main/bssh.sh"
INSTALL_DIR="/usr/local/bin"
DEPENDENCIES="curl sshpass"

install_dependencies() {
    echo "Checking and installing dependencies..."
    sudo apt-get update
    sudo apt-get install -y ${DEPENDENCIES}
}

setup_bssh() {
    echo "Downloading bssh script..."
    curl -sSL "${GIT_URL}" -o "${INSTALL_DIR}/bssh"

    chmod +x "${INSTALL_DIR}/bssh"
    
    if [ ! -x "${INSTALL_DIR}/bssh" ]; then
        echo "Error: Failed to make bssh executable."
        exit 1
    fi
    
    echo "bssh setup completed."
}

main() {
    if command -v bssh >/dev/null 2>&1; then
        echo "bssh is already installed."
        exit 0
    fi

    install_dependencies

    setup_bssh

    echo "bssh is installed in ${INSTALL_DIR}."
    echo "You can now use 'bssh -h' to view the help message."
}

main